/**
 * A number range between two values.
 */
export declare class Interval {
    private _t0;
    private _t1;
    /**
     * @param t0  The start of the interval (could be the interval's min or max)
     * @param t1  The end of the interval (could be the interval's min or max)
     */
    constructor(t0: number, t1: number);
    /**
     * Gets or sets the start value of the interval
     */
    get t0(): number;
    set t0(value: number);
    /**
     * Gets or sets the end value of the interval
     */
    get t1(): number;
    set t1(value: number);
    /**
     * True if [[t0]] is less than [[t1]]
     */
    get isIncreasing(): boolean;
    /**
     * True if [[t0]] is greater than [[t1]]
     */
    get isDecreasing(): boolean;
    /**
     * True if [[t0]] equals [[t1]]
     * In this case, [[length]] will be 0
     */
    get isSingleton(): boolean;
    /**
     * The smaller of [[t0]] and [[t1]]
     */
    get min(): number;
    /**
     * The value in the middle of [[t0]] and [[t1]]
     */
    get mid(): number;
    /**
     * The larger of [[t0]] and [[t1]]
     */
    get max(): number;
    /**
     * The signed distance between [[t0]] and [[t1]].
     * If the interval is decreasing (if [[t1]] is less than [[t0]]), this will return a negative value
     */
    get length(): number;
    /**
     * Switches [[t0]] and [[t1]]
     */
    swap(): void;
    /**
     * Changes interval to [-[[t1]], -[[t0]]]
     */
    reverse(): void;
    /**
     * Expands the interval to include the new value
     * @param toInclude
     * @returns   A new interval containing this interval and the new value
     */
    grow(toInclude: number): Interval;
    /**
     * Joins this and another interval to create one interval that encompasses them both.
     * @param joiner  The interval to join with
     */
    union(joiner: Interval): Interval;
    /**
     * Finds the overlap between this and another interval
     * @param intersector The interval to find the overlap with
     * @returns   An interval representing the overlap. If there is no overlap, returns undefined.
     */
    intersection(intersector: Interval): Interval | undefined;
    /**
     * True if the number is within the interval
     * @param t
     */
    includes(t: number): boolean;
    /**
     * The value at a normalized distance along the interval
     *
     * ```js
     * let interval = new Interval(10, 20)
     * console.log(interval.parameterAt(0.1))
     * // => 11
     * ```
     *
     * @param t   A number between 0 & 1
     */
    valueAt(t: number): number;
}
